@@ -70,7 +70,7 @@ class LsDelCommand(cmd.BaseCommand):
             raise RuntimeError(msg)
 
 
-class LsListCommand(cmd.BaseCommand):
+class LsListCommand(cmd.ReadOnlyCommand):
     def run_idl(self, txn):
         table = self.api.tables['Logical_Switch']
         self.result = [rowview.RowView(r) for r in table.rows.values()]
@@ -190,7 +190,7 @@ class PgAclDelCommand(_AclDelHelper):
     lookup_table = 'Port_Group'
 
 
-class _AclListHelper(cmd.BaseCommand):
+class _AclListHelper(cmd.ReadOnlyCommand):
     def __init__(self, api, entity):
         super(_AclListHelper, self).__init__(api)
         self.entity = entity
@@ -294,7 +294,7 @@ class QoSDelCommand(cmd.BaseCommand):
                 row.delete()
 
 
-class QoSListCommand(cmd.BaseCommand):
+class QoSListCommand(cmd.ReadOnlyCommand):
     def __init__(self, api, switch):
         super(QoSListCommand, self).__init__(api)
         self.switch = switch
@@ -398,7 +398,7 @@ class LspDelCommand(PortDelCommand):
             if_exists)
 
 
-class LspListCommand(cmd.BaseCommand):
+class LspListCommand(cmd.ReadOnlyCommand):
     def __init__(self, api, switch=None):
         super(LspListCommand, self).__init__(api)
         self.switch = switch
@@ -1048,19 +1048,16 @@ class LbDelCommand(cmd.BaseCommand):
     def run_idl(self, txn):
         try:
             lb = self.api.lookup('Load_Balancer', self.lb)
+            if self.vip:
+                if self.vip in lb.vips:
+                    if self.if_exists:
+                        return
+                    lb.delkey('vips', self.vip)
+            else:
+                lb.delete()
         except idlutils.RowNotFound:
             if not self.if_exists:
                 raise
-            return
-        if self.vip:
-            if self.vip in lb.vips:
-                lb.delkey('vips', self.vip)
-            elif not self.if_exists:
-                raise idlutils.RowNotFound(table='Load_Balancer', col=self.vip,
-                                           match=self.lb)
-        # Remove load balancer if vips were not provided or no vips are left.
-        if not self.vip or not lb.vips:
-            lb.delete()
 
 
 class LbListCommand(cmd.ReadOnlyCommand):
